From 4312c89615cd683bc61274d6788a66c1043d120f Mon Sep 17 00:00:00 2001
From: Peter Rotich <peter@osticket.com>
Date: Fri, 12 Sep 2014 18:21:55 +0000
Subject: [PATCH] bug: Allow Resolved tickets to be reopened

---
 include/class.list.php   | 6 +-----
 include/class.ticket.php | 4 ++--
 2 files changed, 3 insertions(+), 7 deletions(-)

diff --git a/include/class.list.php b/include/class.list.php
index 98be80950..f6bc85ea9 100644
--- a/include/class.list.php
+++ b/include/class.list.php
@@ -1014,12 +1014,8 @@ class TicketStatus  extends VerySimpleModel implements CustomListItem {
         return parent::delete();
     }
 
-    function toString() {
-        return $this->getValue();
-    }
-
     function __toString() {
-        return $this->toString();
+        return $this->getName();
     }
 
     static function create($ht) {
diff --git a/include/class.ticket.php b/include/class.ticket.php
index 6e0a07583..e4ccfd076 100644
--- a/include/class.ticket.php
+++ b/include/class.ticket.php
@@ -1154,8 +1154,8 @@ class Ticket {
             }
         }
 
-        // Reopen  if closed.
-        if($this->isClosed()) $this->reopen();
+        // Reopen if NOT open
+        if(!$this->isOpen()) $this->reopen();
 
        /**********   double check auto-response  ************/
         if (!($user = $message->getUser()))
-- 
GitLab